# REL07: How do you design your workload to adapt to changes in demand?

## References

- [AWS REL07](https://docs.aws.amazon.com/wellarchitected/latest/framework/rel-07.html)

## Date

2025-11-27

## Focus Area

Change Management

## Tổng quan

REL07 tập trung vào adapting to demand changes.

## Best Practices

### REL07-BP01: Use automation when obtaining or scaling resources
Auto-scaling.

### REL07-BP02: Obtain resources upon detection of impairment
Scale on failures.

### REL07-BP03: Obtain resources upon detection that more resources are needed
Predictive scaling.

### REL07-BP04: Load test your workload
Capacity testing.

## Checklist

- [ ] Auto-scaling configured
- [ ] Scaling policies defined
- [ ] Load testing performed
